<?php
/*
*
* JetBackup @ package
* Created By Idan Ben-Ezra
*
* Copyrights @ JetApps
* https://www.jetapps.com
*
**/

class Modules_JetBackup5_EventListener implements EventListener {

	public function filterActions() {
		return json_decode(pm_Settings::get('actions', '[]'), true);
	}
	
	public function handleEvent($objectType, $objectId, $action, $oldValues, $newValues) {

		//echo "$action\n";
		//print_r($oldValues);
		//print_r($newValues);
		
		$usernames = [];
		
		switch($action) {
			case 'phys_hosting_update':
				if(isset($newValues['System User']) && $newValues['System User']) $usernames[] = $newValues['System User'];
				if(isset($oldValues['System User']) && $oldValues['System User'] && $oldValues['System User'] != $newValues['System User']) $usernames[] = $oldValues['System User'];
			break;
			case 'phys_hosting_create':
				$usernames[] = $newValues['System User'];
			break;
			case 'phys_hosting_delete':
				$usernames[] = $oldValues['System User'];
			break;
			case 'client_update':
			case 'reseller_update':
				if(isset($newValues['Login Name']) && $newValues['Login Name']) $usernames[] = 'hash:xxh32|'.$newValues['Login Name'];
				if(isset($oldValues['Login Name']) && $oldValues['Login Name'] && $oldValues['Login Name'] != $newValues['Login Name']) $usernames[] = 'hash:xxh32|'.$oldValues['Login Name'];
			break;
			case 'client_create':
			case 'reseller_create':
				$usernames[] = 'hash:xxh32|'.$newValues['Login Name'];
			break;
			case 'client_delete':
			case 'reseller_delete':
				$usernames[] = 'hash:xxh32|'.$oldValues['Login Name'];
			break;
			case 'client_status_update':
				if($oldValues['Status'] != $newValues['Status']) $usernames[] = 'hash:xxh32|'.$newValues['Login Name'];
			break;
			
			case 'template_domain_create':
			case 'template_domain_delete':

				$id = $newValues['Domain template'] ?: $oldValues['Domain template'];
				$request = "<service-plan><get><filter><id>$id</id></filter></get></service-plan>";
				$owner_id = (string) pm_ApiRpc::getService()->call($request)->{"service-plan"}->get->result->{"owner-id"};
				
				if($owner_id == 1) $usernames[] = 'root';
				else {
					$client = pm_Client::getByClientId($owner_id);
					$usernames[] = 'hash:xxh32|'.$client->getLogin();
				}
				
			break;

			case 'template_admin_create':
			case 'template_admin_delete':
			case 'template_reseller_create':
			case 'template_reseller_delete':
				$usernames[] = 'root';
			break;
		}
		
		if(sizeof($usernames)) {
			pm_ApiCli::callSbin("modules/jetbackup5/sync_accounts", [implode(',', $usernames)]);
			echo "Syncing accounts: " . implode(", ", $usernames) . "\n";
		}
	}
}
return new Modules_JetBackup5_EventListener();